0.0.3
-----

* Repackage to hatch/pyproject
* Switch to smbus2

0.0.2
-----

* Add `set_multiple_pixels`
* Updated packaging
* Linting & minor improvements to docstrings

0.0.1
-----

* Initial release

